﻿using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace DarwinDecriptor.Test
{
    using System;

    [TestClass]
    public class GuidConverterTest
    {
        [TestMethod]
        [ExpectedException(typeof(ArgumentNullException))]
        public void DecodeNullEncodedGuidPasedThrowExceprtion()
        {
            var target = new GuidConverter();
            target.Decode(null);
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void DecodeEmptyEncodedGuidPasedThrowExceprtion()
        {
            var target = new GuidConverter();
            target.Decode(string.Empty);
        }

        [TestMethod]
        public void DecodeValidEncodedGuidPasedReturnDecodedGuid()
        {
            var target = new GuidConverter();
            var encodedGuid = "ykG^V5!!!!4!!!!MKKSk";
            var expectedDecodedGuid = Guid.Parse("{91140000-0011-0000-1000-0000000FF1CE}");

            var actual = target.Decode(encodedGuid);

            Assert.AreEqual(expectedDecodedGuid, actual);
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void DecodeInvalidGuidPassedThrowException()
        {
            var target = new GuidConverter();
            var encodedGuid = "ykG^V5!!!!4!!!!MKKS#";
            
            target.Decode(encodedGuid);
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void DecodeShortGuidPassedThrowException()
        {
            var target = new GuidConverter();
            var encodedGuid = "yk";

            target.Decode(encodedGuid);
        }

        [TestMethod]
        public void EncodeGuidPassedReturnEncodedDarwinDescriptor()
        {
            var expected = "ykG^V5!!!!4!!!!MKKSk";
            var target = new GuidConverter();
           
            var actual = target.Encode(Guid.Parse("{91140000-0011-0000-1000-0000000FF1CE}"));

            Assert.AreEqual(expected, actual);
        }
    }
}
